@@ -9,9 +9,9 @@ from typing import Any
 
 import tlz as toolz
 
+import dask
 from dask.base import clone_key, get_name_from_key, tokenize
 from dask.core import flatten, keys_in_tasks, reverse_dict
-from dask.delayed import unpack_collections
 from dask.highlevelgraph import HighLevelGraph, Layer
 from dask.optimization import SubgraphCallable, fuse
 from dask.utils import (
@@ -303,7 +303,7 @@ def blockwise(
     ``*arrind_pairs`` is similar to those in `make_blockwise_graph`, but in addition to
     allowing for collections it can accept BlockwiseDep instances, which allows for lazy
     evaluation of arguments to ``func`` which might be different for different
-    chunks/paritions.
+    chunks/partitions.
 
     See Also
     --------
@@ -689,14 +689,14 @@ class Blockwise(Layer):
             state["output"],
             state["output_indices"],
             *indices,
-            new_axes=state["new_axes"],
             numblocks=state["numblocks"],
             concatenate=state["concatenate"],
+            new_axes=state["new_axes"],
             output_blocks=state["output_blocks"],
             dims=state["dims"],
-            return_key_deps=True,
             deserializing=True,
             func_future_args=state["func_future_args"],
+            return_key_deps=True,
             io_deps=io_deps,
         )
         g_deps = state["global_dependencies"]
@@ -972,7 +972,6 @@ def make_blockwise_graph(
     func_future_args=None,
     return_key_deps=False,
     io_deps=None,
-    **kwargs,
 ):
     """Tensor operation
 
@@ -1107,15 +1106,6 @@ def make_blockwise_graph(
         concatenate,
     )
 
-    # Unpack delayed objects in kwargs
-    dsk2 = {}
-    if kwargs:
-        task, dsk2 = unpack_collections(kwargs)
-        if dsk2:
-            kwargs2 = task
-        else:
-            kwargs2 = kwargs
-
     # Apply Culling.
     # Only need to construct the specified set of output blocks.
     # Note that we must convert itertools.product to list,
@@ -1167,35 +1157,22 @@ def make_blockwise_graph(
             deps.update(func_future_args)
             args += list(func_future_args)
 
+        # Construct a function/args/kwargs dict if we
+        # do not have a nested task (i.e. concatenate=False).
+        # TODO: Avoid using the iterate_collection-version
+        # of to_serialize if we know that are no embedded
+        # Serialized/Serialize objects in args and/or kwargs.
         if deserializing and isinstance(func, bytes):
-            # Construct a function/args/kwargs dict if we
-            # do not have a nested task (i.e. concatenate=False).
-            # TODO: Avoid using the iterate_collection-version
-            # of to_serialize if we know that are no embeded
-            # Serialized/Serialize objects in args and/or kwargs.
-            if kwargs:
-                dsk[out_key] = {
-                    "function": func,
-                    "args": to_serialize(args),
-                    "kwargs": to_serialize(kwargs2),
-                }
-            else:
-                dsk[out_key] = {"function": func, "args": to_serialize(args)}
+            dsk[out_key] = {"function": func, "args": to_serialize(args)}
         else:
-            if kwargs:
-                val = (apply, func, args, kwargs2)
-            else:
-                args.insert(0, func)
-                val = tuple(args)
+            args.insert(0, func)
+            val = tuple(args)
             # May still need to serialize (if concatenate=True)
             dsk[out_key] = to_serialize(val) if deserializing else val
 
         if return_key_deps:
             key_deps[out_key] = deps
 
-    if dsk2:
-        dsk.update(ensure_dict(dsk2))
-
     if return_key_deps:
 
         # Add valid-key dependencies from io_deps
@@ -1351,10 +1328,9 @@ def _optimize_blockwise(full_graph, keys=()):
                 ):
                     stack.append(dep)
                     continue
-                if (
-                    blockwise_layers
-                    and layers[next(iter(blockwise_layers))].annotations
-                    != layers[dep].annotations
+                if blockwise_layers and not _can_fuse_annotations(
+                    layers[next(iter(blockwise_layers))].annotations,
+                    layers[dep].annotations,
                 ):
                     stack.append(dep)
                     continue
@@ -1412,6 +1388,60 @@ def _unique_dep(dep, ind):
     return dep + "_" + "_".join(str(i) for i in list(ind))
 
 
+def _can_fuse_annotations(a: dict | None, b: dict | None) -> bool:
+    """
+    Treat the special annotation keys, as fusable since we can apply simple
+    rules to capture their intent in a fused layer.
+    """
+    if a == b:
+        return True
+
+    if dask.config.get("optimization.annotations.fuse") is False:
+        return False
+
+    fusable = {"retries", "priority", "resources", "workers", "allow_other_workers"}
+    if (not a or all(k in fusable for k in a)) and (
+        not b or all(k in fusable for k in b)
+    ):
+        return True
+
+    return False
+
+
+def _fuse_annotations(*args: dict) -> dict:
+    """
+    Given an iterable of annotations dictionaries, fuse them according
+    to some simple rules.
+    """
+    # First, do a basic dict merge -- we are presuming that these have already
+    # been gated by `_can_fuse_annotations`.
+    annotations = toolz.merge(*args)
+    # Max of layer retries
+    retries = [a["retries"] for a in args if "retries" in a]
+    if retries:
+        annotations["retries"] = max(retries)
+    # Max of layer priorities
+    priorities = [a["priority"] for a in args if "priority" in a]
+    if priorities:
+        annotations["priority"] = max(priorities)
+    # Max of all the layer resources
+    resources = [a["resources"] for a in args if "resources" in a]
+    if resources:
+        annotations["resources"] = toolz.merge_with(max, *resources)
+    # Intersection of all the worker restrictions
+    workers = [a["workers"] for a in args if "workers" in a]
+    if workers:
+        annotations["workers"] = list(set.intersection(*[set(w) for w in workers]))
+    # More restrictive of allow_other_workers
+    allow_other_workers = [
+        a["allow_other_workers"] for a in args if "allow_other_workers" in a
+    ]
+    if allow_other_workers:
+        annotations["allow_other_workers"] = all(allow_other_workers)
+
+    return annotations
+
+
 def rewrite_blockwise(inputs):
     """Rewrite a stack of Blockwise expressions into a single blockwise expression
 
@@ -1435,6 +1465,9 @@ def rewrite_blockwise(inputs):
         # Fast path: if there's only one input we can just use it as-is.
         return inputs[0]
 
+    fused_annotations = _fuse_annotations(
+        *[i.annotations for i in inputs if i.annotations]
+    )
     inputs = {inp.output: inp for inp in inputs}
     dependencies = {
         inp.output: {d for d, v in inp.indices if v is not None and d in inputs}
@@ -1560,7 +1593,7 @@ def rewrite_blockwise(inputs):
         numblocks=numblocks,
         new_axes=new_axes,
         concatenate=concatenate,
-        annotations=inputs[root].annotations,
+        annotations=fused_annotations,
         io_deps=io_deps,
     )
 
