@@ -78,6 +78,9 @@ def s3_base():
     with ensure_safe_environment_variables():
         os.environ["AWS_ACCESS_KEY_ID"] = "foobar_key"
         os.environ["AWS_SECRET_ACCESS_KEY"] = "foobar_secret"
+        # Ignore any local AWS credentials/config files as they can interfere with moto
+        os.environ["AWS_SHARED_CREDENTIALS_FILE"] = ""
+        os.environ["AWS_CONFIG_FILE"] = ""
 
         # pipe to null to avoid logging in terminal
         proc = subprocess.Popen(
@@ -377,7 +380,7 @@ def test_read_bytes_delimited(s3, blocksize, s3so):
 
 @pytest.mark.parametrize(
     "fmt,blocksize",
-    [(fmt, None) for fmt in compr] + [(fmt, 10) for fmt in compr],  # type: ignore
+    [(fmt, None) for fmt in compr] + [(fmt, 10) for fmt in compr],
 )
 def test_compression(s3, fmt, blocksize, s3so):
     if fmt not in compress:
@@ -480,7 +483,7 @@ def test_parquet(s3, engine, s3so, metadata_file):
     assert "part.0.parquet" in files
 
     df2 = dd.read_parquet(
-        url, index="foo", gather_statistics=True, engine=engine, storage_options=s3so
+        url, index="foo", calculate_divisions=True, engine=engine, storage_options=s3so
     )
     assert len(df2.divisions) > 1
 
@@ -573,6 +576,7 @@ def test_parquet_append(s3, engine, s3so):
         engine=engine,
         storage_options=s3so,
         write_index=False,
+        write_metadata_file=True,
     )
     df.to_parquet(
         url,
@@ -613,7 +617,13 @@ def test_parquet_wstoragepars(s3, s3so, engine):
 
     data = pd.DataFrame({"i32": np.array([0, 5, 2, 5])})
     df = dd.from_pandas(data, chunksize=500)
-    df.to_parquet(url, engine=engine, write_index=False, storage_options=s3so)
+    df.to_parquet(
+        url,
+        engine=engine,
+        write_index=False,
+        storage_options=s3so,
+        write_metadata_file=True,
+    )
 
     dd.read_parquet(
         url,
