@@ -15,8 +15,10 @@ from pandas.api.types import (
     union_categoricals,
 )
 
+from dask.array.core import Array
 from dask.array.dispatch import percentile_lookup
 from dask.array.percentile import _percentile
+from dask.backends import CreationDispatch, DaskBackendEntrypoint
 from dask.dataframe.core import DataFrame, Index, Scalar, Series, _Frame
 from dask.dataframe.dispatch import (
     categorical_dtype_dispatch,
@@ -29,8 +31,10 @@ from dask.dataframe.dispatch import (
     is_categorical_dtype_dispatch,
     make_meta_dispatch,
     make_meta_obj,
+    meta_lib_from_array,
     meta_nonempty,
     pyarrow_schema_dispatch,
+    to_pandas_dispatch,
     tolist_dispatch,
     union_categoricals_dispatch,
 )
@@ -45,6 +49,130 @@ from dask.dataframe.utils import (
 from dask.sizeof import SimpleSizeof, sizeof
 from dask.utils import is_arraylike, is_series_like, typename
 
+
+class DataFrameBackendEntrypoint(DaskBackendEntrypoint):
+    """Dask-DataFrame version of ``DaskBackendEntrypoint``
+
+    See Also
+    --------
+    PandasBackendEntrypoint
+    """
+
+    @staticmethod
+    def from_dict(data: dict, *, npartitions: int, **kwargs):
+        """Create a DataFrame collection from a dictionary
+
+        Parameters
+        ----------
+        data : dict
+            Of the form {field : array-like} or {field : dict}.
+        npartitions : int
+            The desired number of output partitions.
+        **kwargs :
+            Optional backend kwargs.
+
+        See Also
+        --------
+        dask.dataframe.io.io.from_dict
+        """
+        raise NotImplementedError
+
+    @staticmethod
+    def read_parquet(path: str | list, **kwargs):
+        """Read Parquet files into a DataFrame collection
+
+        Parameters
+        ----------
+        path : str or list
+            Source path(s).
+        **kwargs :
+            Optional backend kwargs.
+
+        See Also
+        --------
+        dask.dataframe.io.parquet.core.read_parquet
+        """
+        raise NotImplementedError
+
+    @staticmethod
+    def read_json(url_path: str | list, **kwargs):
+        """Read json files into a DataFrame collection
+
+        Parameters
+        ----------
+        url_path : str or list
+            Source path(s).
+        **kwargs :
+            Optional backend kwargs.
+
+        See Also
+        --------
+        dask.dataframe.io.json.read_json
+        """
+        raise NotImplementedError
+
+    @staticmethod
+    def read_orc(path: str | list, **kwargs):
+        """Read ORC files into a DataFrame collection
+
+        Parameters
+        ----------
+        path : str or list
+            Source path(s).
+        **kwargs :
+            Optional backend kwargs.
+
+        See Also
+        --------
+        dask.dataframe.io.orc.core.read_orc
+        """
+        raise NotImplementedError
+
+    @staticmethod
+    def read_csv(urlpath: str | list, **kwargs):
+        """Read CSV files into a DataFrame collection
+
+        Parameters
+        ----------
+        urlpath : str or list
+            Source path(s).
+        **kwargs :
+            Optional backend kwargs.
+
+        See Also
+        --------
+        dask.dataframe.io.csv.read_csv
+        """
+        raise NotImplementedError
+
+    @staticmethod
+    def read_hdf(pattern: str | list, key: str, **kwargs):
+        """Read HDF5 files into a DataFrame collection
+
+        Parameters
+        ----------
+        pattern : str or list
+            Source path(s).
+        key : str
+            Group identifier in the store.
+        **kwargs :
+            Optional backend kwargs.
+
+        See Also
+        --------
+        dask.dataframe.io.hdf.read_hdf
+        """
+        raise NotImplementedError
+
+
+dataframe_creation_dispatch = CreationDispatch(
+    module_name="dataframe",
+    default="pandas",
+    entrypoint_class=DataFrameBackendEntrypoint,
+    name="dataframe_creation_dispatch",
+)
+
+
 ##########
 # Pandas #
 ##########
@@ -308,6 +436,18 @@ def _nonempty_series(s, idx=None):
     return out
 
 
+@meta_lib_from_array.register(Array)
+def _meta_lib_from_array_da(x):
+    # Use x._meta for dask arrays
+    return meta_lib_from_array(x._meta)
+
+
+@meta_lib_from_array.register(np.ndarray)
+def _meta_lib_from_array_numpy(x):
+    # numpy -> pandas
+    return pd
+
+
 @union_categoricals_dispatch.register(
     (pd.DataFrame, pd.Series, pd.Index, pd.Categorical)
 )
@@ -559,6 +699,34 @@ def percentile(a, q, interpolation="linear"):
     return _percentile(a, q, interpolation)
 
 
+@to_pandas_dispatch.register((pd.DataFrame, pd.Series, pd.Index))
+def to_pandas_dispatch_from_pandas(data, **kwargs):
+    return data
+
+
+class PandasBackendEntrypoint(DataFrameBackendEntrypoint):
+    """Pandas-Backend Entrypoint Class for Dask-DataFrame
+
+    Note that all DataFrame-creation functions are defined
+    and registered 'in-place' within the ``dask.dataframe``
+    ``io`` module.
+    """
+
+    @classmethod
+    def to_backend_dispatch(cls):
+        return to_pandas_dispatch
+
+    @classmethod
+    def to_backend(cls, data: _Frame, **kwargs):
+        if isinstance(data._meta, (pd.DataFrame, pd.Series, pd.Index)):
+            # Already a pandas-backed collection
+            return data
+        return data.map_partitions(cls.to_backend_dispatch(), **kwargs)
+
+
+dataframe_creation_dispatch.register_backend("pandas", PandasBackendEntrypoint())
+
+
 ######################################
 # cuDF: Pandas Dataframes on the GPU #
 ######################################
@@ -574,3 +742,19 @@ def percentile(a, q, interpolation="linear"):
 @percentile_lookup.register_lazy("cudf")
 def _register_cudf():
     import dask_cudf  # noqa: F401
+
+
+@meta_lib_from_array.register_lazy("cupy")
+def _register_cupy_to_cudf():
+    # Handle cupy.ndarray -> cudf.DataFrame dispatching
+    try:
+        import cudf
+        import cupy
+
+        @meta_lib_from_array.register(cupy.ndarray)
+        def meta_lib_from_array_cupy(x):
+            # cupy -> cudf
+            return cudf
+
+    except ImportError:
+        pass
