@@ -11,18 +11,21 @@ import numpy as np
 import pandas as pd
 
 import dask.array as da
-from dask.base import tokenize
+from dask.base import is_dask_collection, tokenize
 from dask.blockwise import BlockwiseDepDict, blockwise
+from dask.dataframe.backends import dataframe_creation_dispatch
 from dask.dataframe.core import (
     DataFrame,
     Index,
     Series,
     _concat,
     _emulate,
+    _Frame,
     apply_and_enforce,
     has_parallel_type,
     new_dd_object,
 )
+from dask.dataframe.dispatch import meta_lib_from_array
 from dask.dataframe.io.utils import DataFrameIOFunction
 from dask.dataframe.utils import (
     check_meta,
@@ -57,7 +60,7 @@ def _meta_from_array(x, columns=None, index=None, meta=None):
         index = index._meta
 
     if meta is None:
-        meta = pd.DataFrame()
+        meta = meta_lib_from_array(x).DataFrame()
 
     if getattr(x.dtype, "names", None) is not None:
         # record array has named columns
@@ -304,6 +307,59 @@ def from_pandas(
     return new_dd_object(dsk, name, data, divisions)
 
 
+@dataframe_creation_dispatch.register_inplace("pandas")
+def from_dict(
+    data,
+    npartitions,
+    orient="columns",
+    dtype=None,
+    columns=None,
+    constructor=pd.DataFrame,
+):
+    """
+    Construct a Dask DataFrame from a Python Dictionary
+
+    Parameters
+    ----------
+    data : dict
+        Of the form {field : array-like} or {field : dict}.
+    npartitions : int
+        The number of partitions of the index to create. Note that depending on
+        the size and index of the dataframe, the output may have fewer
+        partitions than requested.
+    orient : {'columns', 'index', 'tight'}, default 'columns'
+        The "orientation" of the data. If the keys of the passed dict
+        should be the columns of the resulting DataFrame, pass 'columns'
+        (default). Otherwise if the keys should be rows, pass 'index'.
+        If 'tight', assume a dict with keys
+        ['index', 'columns', 'data', 'index_names', 'column_names'].
+    dtype: bool
+        Data type to force, otherwise infer.
+    columns: string, optional
+        Column labels to use when ``orient='index'``. Raises a ValueError
+        if used with ``orient='columns'`` or ``orient='tight'``.
+    constructor: class, default pd.DataFrame
+        Class with which ``from_dict`` should be called with.
+
+    Examples
+    --------
+    >>> import dask.dataframe as dd
+    >>> ddf = dd.from_dict({"num1": [1, 2, 3, 4], "num2": [7, 8, 9, 10]}, npartitions=2)
+    """
+
+    collection_types = {type(v) for v in data.values() if is_dask_collection(v)}
+    if collection_types:
+        raise NotImplementedError(
+            "from_dict doesn't currently support Dask collections as inputs. "
+            f"Objects of type {collection_types} were given in the input dict."
+        )
+
+    return from_pandas(
+        constructor.from_dict(data, orient, dtype, columns),
+        npartitions,
+    )
+
+
 def _partition_from_array(data, index=None, initializer=None, **kwargs):
     """Create a Dask partition for either a DataFrame or Series.
 
@@ -1020,5 +1076,30 @@ def from_map(
     return new_dd_object(graph, name, meta, divisions)
 
 
+def to_backend(ddf: _Frame, backend: str | None = None, **kwargs):
+    """Move a DataFrame collection to a new backend
+
+    Parameters
+    ----------
+    ddf : DataFrame, Series, or Index
+        The input dataframe collection.
+    backend : str, Optional
+        The name of the new backend to move to. The default
+        is the current "dataframe.backend" configuration.
+
+    Returns
+    -------
+    dask.DataFrame, dask.Series or dask.Index
+        A new dataframe collection with the backend
+        specified by ``backend``.
+    """
+    # Get desired backend
+    backend = backend or dataframe_creation_dispatch.backend
+    # Check that "backend" has a registered entrypoint
+    backend_entrypoint = dataframe_creation_dispatch.dispatch(backend)
+    # Call `DataFrameBackendEntrypoint.to_backend`
+    return backend_entrypoint.to_backend(ddf, **kwargs)
+
+
 DataFrame.to_records.__doc__ = to_records.__doc__
 DataFrame.to_bag.__doc__ = to_bag.__doc__
