@@ -15,7 +15,23 @@ except ImportError:
 
 def _is_local_fs(fs):
     """Check if an fsspec file-system is local"""
-    return fs and isinstance(fs, LocalFileSystem)
+    return fs and (
+        isinstance(fs, LocalFileSystem)
+        # Check wrapped pyarrow filesystem
+        or _is_local_fs_pyarrow(fs)
+    )
+
+
+def _is_local_fs_pyarrow(fs):
+    """Check if a pyarrow-based file-system is local"""
+    if fs:
+        if hasattr(fs, "fs"):
+            # ArrowFSWrapper will have an "fs" attribute
+            return _is_local_fs_pyarrow(fs.fs)
+        elif hasattr(fs, "type_name"):
+            # pa.fs.LocalFileSystem will have "type_name" attribute
+            return fs.type_name == "local"
+    return False
 
 
 def _get_pyarrow_dtypes(schema, categories, use_nullable_dtypes=False):
