@@ -17,7 +17,12 @@ import pytest
 import dask
 import dask.dataframe as dd
 from dask.base import compute_as_if_collection
-from dask.dataframe._compat import PANDAS_GT_120, assert_categorical_equal, tm
+from dask.dataframe._compat import (
+    PANDAS_GT_120,
+    PANDAS_GT_140,
+    assert_categorical_equal,
+    tm,
+)
 from dask.dataframe.shuffle import (
     _noop,
     maybe_buffered_partd,
@@ -179,15 +184,26 @@ def test_partitioning_index_categorical_on_values():
     "npartitions", [1, 4, 7, pytest.param(23, marks=pytest.mark.slow)]
 )
 def test_set_index_general(npartitions, shuffle_method):
+    names = ["alice", "bob", "ricky"]
     df = pd.DataFrame(
-        {"x": np.random.random(100), "y": np.random.random(100) // 0.2},
+        {
+            "x": np.random.random(100),
+            "y": np.random.random(100) // 0.2,
+            "z": np.random.choice(names, 100),
+        },
         index=np.random.random(100),
     )
+    # Ensure extension dtypes work
+    # NOTE: Older version of pandas have known issues with extension dtypes.
+    # We generally expect extension dtypes to work well when using `pandas>=1.4.0`.
+    if PANDAS_GT_140:
+        df = df.astype({"x": "Float64", "z": "string"})
 
     ddf = dd.from_pandas(df, npartitions=npartitions)
 
     assert_eq(df.set_index("x"), ddf.set_index("x", shuffle=shuffle_method))
     assert_eq(df.set_index("y"), ddf.set_index("y", shuffle=shuffle_method))
+    assert_eq(df.set_index("z"), ddf.set_index("z", shuffle=shuffle_method))
     assert_eq(df.set_index(df.x), ddf.set_index(ddf.x, shuffle=shuffle_method))
     assert_eq(
         df.set_index(df.x + df.y), ddf.set_index(ddf.x + ddf.y, shuffle=shuffle_method)
@@ -195,6 +211,28 @@ def test_set_index_general(npartitions, shuffle_method):
     assert_eq(df.set_index(df.x + 1), ddf.set_index(ddf.x + 1, shuffle=shuffle_method))
 
 
+@pytest.mark.skipif(
+    not PANDAS_GT_140, reason="Only test `string[pyarrow]` on recent versions of pandas"
+)
+@pytest.mark.parametrize(
+    "string_dtype", ["string[python]", "string[pyarrow]", "object"]
+)
+def test_set_index_string(shuffle_method, string_dtype):
+    if string_dtype == "string[pyarrow]":
+        pytest.importorskip("pyarrow")
+    names = ["alice", "bob", "ricky"]
+    df = pd.DataFrame(
+        {
+            "x": np.random.random(100),
+            "y": np.random.choice(names, 100),
+        },
+        index=np.random.random(100),
+    )
+    df = df.astype({"y": string_dtype})
+    ddf = dd.from_pandas(df, npartitions=10)
+    assert_eq(df.set_index("y"), ddf.set_index("y", shuffle=shuffle_method))
+
+
 def test_set_index_self_index(shuffle_method):
     df = pd.DataFrame(
         {"x": np.random.random(100), "y": np.random.random(100) // 0.2},
@@ -1072,7 +1110,7 @@ def test_set_index_timestamp():
     df2 = df.set_index("A")
     ddf_new_div = ddf.set_index("A", divisions=divisions)
     for (ts1, ts2) in zip(divisions, ddf_new_div.divisions):
-        assert ts1.value == ts2.value
+        assert ts1.timetuple() == ts2.timetuple()
         assert ts1.tz == ts2.tz
 
     assert_eq(df2, ddf_new_div, **CHECK_FREQ)
@@ -1405,11 +1443,11 @@ def test_sort_values_single_partition(nelem, by, ascending):
     "data",
     [
         {
-            "a": list(range(50)) + [None] * 50 + list(range(50, 100)),  # type: ignore
-            "b": [None] * 100 + list(range(100, 150)),  # type: ignore
+            "a": list(range(50)) + [None] * 50 + list(range(50, 100)),
+            "b": [None] * 100 + list(range(100, 150)),
         },
         {
-            "a": list(range(15)) + [None] * 5,  # type: ignore
+            "a": list(range(15)) + [None] * 5,
             "b": list(reversed(range(20))),
         },
     ],
@@ -1475,3 +1513,28 @@ def test_sort_values_bool_ascending():
     # attempt to sort with list of ascending booleans
     with pytest.raises(NotImplementedError):
         ddf.sort_values(by="a", ascending=[True, False])
+
+
+@pytest.mark.parametrize("npartitions", [1, 3])
+def test_sort_values_timestamp(npartitions):
+    # Regression test for https://github.com/dask/dask/issues/9641
+    df = pd.DataFrame.from_records(
+        [
+            [pd.Timestamp("2002-01-11 21:00:01+0000", tz="UTC"), 4223, 54719.0],
+            [pd.Timestamp("2002-01-14 21:00:01+0000", tz="UTC"), 6942, 19223.0],
+            [pd.Timestamp("2002-01-15 21:00:01+0000", tz="UTC"), 12551, 72865.0],
+            [pd.Timestamp("2002-01-23 21:00:01+0000", tz="UTC"), 6005, 57670.0],
+            [pd.Timestamp("2002-01-29 21:00:01+0000", tz="UTC"), 2043, 58600.0],
+            [pd.Timestamp("2002-02-01 21:00:01+0000", tz="UTC"), 6909, 8459.0],
+            [pd.Timestamp("2002-01-14 21:00:01+0000", tz="UTC"), 5326, 77339.0],
+            [pd.Timestamp("2002-01-14 21:00:01+0000", tz="UTC"), 4711, 54135.0],
+            [pd.Timestamp("2002-01-22 21:00:01+0000", tz="UTC"), 103, 57627.0],
+            [pd.Timestamp("2002-01-30 21:00:01+0000", tz="UTC"), 16862, 54458.0],
+            [pd.Timestamp("2002-01-31 21:00:01+0000", tz="UTC"), 4143, 56280.0],
+        ],
+        columns=["time", "id1", "id2"],
+    )
+    ddf = dd.from_pandas(df, npartitions=npartitions)
+    result = ddf.sort_values("time")
+    expected = df.sort_values("time")
+    assert_eq(result, expected)
